@@ -63,8 +63,8 @@
 
 using namespace Konsole;
 
-EditProfileDialog::EditProfileDialog(QWidget *aParent) :
-    QDialog(aParent),
+EditProfileDialog::EditProfileDialog(QWidget *parent) :
+    QDialog(parent),
     _ui(nullptr),
     _tempProfile(nullptr),
     _profile(nullptr),
@@ -359,6 +359,7 @@ void EditProfileDialog::setupGeneralPage(const Profile::Ptr profile)
 
     // window options
     _ui->showTerminalSizeHintButton->setChecked(profile->showTerminalSizeHint());
+    _ui->dimWhenInactiveCheckbox->setChecked(profile->dimWhenInactive());
 
     // signals and slots
     connect(_ui->dirSelectButton, &QToolButton::clicked, this,
@@ -384,6 +385,9 @@ void EditProfileDialog::setupGeneralPage(const Profile::Ptr profile)
 
     connect(_ui->showTerminalSizeHintButton, &QCheckBox::toggled, this,
             &Konsole::EditProfileDialog::showTerminalSizeHint);
+
+    connect(_ui->dimWhenInactiveCheckbox, &QCheckBox::toggled, this,
+            &Konsole::EditProfileDialog::setDimWhenInactive);
 }
 
 void EditProfileDialog::showEnvironmentEditor()
@@ -457,6 +461,11 @@ void EditProfileDialog::showTerminalSizeHint(bool value)
     updateTempProfileProperty(Profile::ShowTerminalSizeHint, value);
 }
 
+void EditProfileDialog::setDimWhenInactive(bool value)
+{
+    updateTempProfileProperty(Profile::DimWhenInactive, value);
+}
+
 void EditProfileDialog::tabTitleFormatChanged(const QString &format)
 {
     updateTempProfileProperty(Profile::LocalTabTitleFormat, format);
@@ -624,6 +633,7 @@ void EditProfileDialog::setAntialiasText(bool enable)
 
     // update preview to reflect text smoothing state
     fontSelected(profileFont);
+    preview(Profile::AntiAliasFonts, enable);
     updateTempProfileProperty(Profile::AntiAliasFonts, enable);
 }
 
@@ -657,7 +667,7 @@ void EditProfileDialog::updateColorSchemeList(const QString &selectedColorScheme
 
     const ColorScheme *selectedColorScheme = ColorSchemeManager::instance()->findColorScheme(selectedColorSchemeName);
 
-    QStandardItemModel *model = qobject_cast<QStandardItemModel *>(_ui->colorSchemeList->model());
+    auto *model = qobject_cast<QStandardItemModel *>(_ui->colorSchemeList->model());
 
     Q_ASSERT(model);
 
@@ -700,7 +710,7 @@ void EditProfileDialog::updateKeyBindingsList(const QString &selectKeyBindingsNa
         _ui->keyBindingList->setModel(new QStandardItemModel(this));
     }
 
-    QStandardItemModel *model = qobject_cast<QStandardItemModel *>(_ui->keyBindingList->model());
+    auto *model = qobject_cast<QStandardItemModel *>(_ui->keyBindingList->model());
 
     Q_ASSERT(model);
 
@@ -888,8 +898,6 @@ void EditProfileDialog::removeColorScheme()
         manager->deleteLater();
     });
     manager->checkForInstalled();
-
-    return;
 }
 
 void EditProfileDialog::gotNewColorSchemes(const KNS3::Entry::List &changedEntries)
@@ -1024,7 +1032,7 @@ void EditProfileDialog::colorSchemeSelected()
 
     if (!selected.isEmpty()) {
         QAbstractItemModel *model = _ui->colorSchemeList->model();
-        const ColorScheme *colors = model->data(selected.first(), Qt::UserRole + 1).value<const ColorScheme *>();
+        const auto *colors = model->data(selected.first(), Qt::UserRole + 1).value<const ColorScheme *>();
         if (colors != nullptr) {
             updateTempProfileProperty(Profile::ColorScheme, colors->name());
             previewColorScheme(selected.first());
@@ -1179,7 +1187,7 @@ void EditProfileDialog::keyBindingSelected()
 
     if (!selected.isEmpty()) {
         QAbstractItemModel *model = _ui->keyBindingList->model();
-        const KeyboardTranslator *translator = model->data(selected.first(), Qt::UserRole + 1)
+        const auto *translator = model->data(selected.first(), Qt::UserRole + 1)
                                                .value<const KeyboardTranslator *>();
         if (translator != nullptr) {
             updateTempProfileProperty(Profile::KeyBindings, translator->name());
@@ -1274,7 +1282,7 @@ void EditProfileDialog::setupRadio(const QVector<RadioOption>& possibilities, in
 void EditProfileDialog::setupScrollingPage(const Profile::Ptr profile)
 {
     // setup scrollbar radio
-    int scrollBarPosition = profile->property<int>(Profile::ScrollBarPosition);
+    auto scrollBarPosition = profile->property<int>(Profile::ScrollBarPosition);
 
     const auto positions = QVector<RadioOption>{ {_ui->scrollBarHiddenButton, Enum::ScrollBarHidden, SLOT(hideScrollBar())},
                                 {_ui->scrollBarLeftButton, Enum::ScrollBarLeft, SLOT(showScrollBarLeft())},
@@ -1283,7 +1291,7 @@ void EditProfileDialog::setupScrollingPage(const Profile::Ptr profile)
     setupRadio(positions, scrollBarPosition);
 
     // setup scrollback type radio
-    int scrollBackType = profile->property<int>(Profile::HistoryMode);
+    auto scrollBackType = profile->property<int>(Profile::HistoryMode);
     _ui->historySizeWidget->setMode(Enum::HistoryModeEnum(scrollBackType));
     connect(_ui->historySizeWidget, &Konsole::HistorySizeWidget::historyModeChanged, this,
             &Konsole::EditProfileDialog::historyModeChanged);
@@ -1293,7 +1301,7 @@ void EditProfileDialog::setupScrollingPage(const Profile::Ptr profile)
     _ui->historySizeWidget->setLineCount(historySize);
 
     // setup scrollpageamount type radio
-    int scrollFullPage = profile->property<int>(Profile::ScrollFullPage);
+    auto scrollFullPage = profile->property<int>(Profile::ScrollFullPage);
 
     const auto pageamounts = QVector<RadioOption>{
         {_ui->scrollHalfPage, Enum::ScrollPageHalf, SLOT(scrollHalfPage())},
@@ -1389,7 +1397,7 @@ void EditProfileDialog::setupMousePage(const Profile::Ptr profile)
     setupCheckBoxes(options, profile);
 
     // setup middle click paste mode
-    const int middleClickPasteMode = profile->property<int>(Profile::MiddleClickPasteMode);
+    const auto middleClickPasteMode = profile->property<int>(Profile::MiddleClickPasteMode);
     const auto pasteModes = QVector<RadioOption> {
         {_ui->pasteFromX11SelectionButton, Enum::PasteFromX11Selection, SLOT(pasteFromX11Selection())},
         {_ui->pasteFromClipboardButton, Enum::PasteFromClipboard, SLOT(pasteFromClipboard())}    };
@@ -1400,7 +1408,7 @@ void EditProfileDialog::setupMousePage(const Profile::Ptr profile)
 
     connect(_ui->wordCharacterEdit, &QLineEdit::textChanged, this, &Konsole::EditProfileDialog::wordCharactersChanged);
 
-    int tripleClickMode = profile->property<int>(Profile::TripleClickMode);
+    auto tripleClickMode = profile->property<int>(Profile::TripleClickMode);
     _ui->tripleClickModeCombo->setCurrentIndex(tripleClickMode);
 
     connect(_ui->tripleClickModeCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &Konsole::EditProfileDialog::TripleClickModeChanged);
@@ -1429,13 +1437,17 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr profile)
         {
             _ui->enableBidiRenderingButton, Profile::BidiRenderingEnabled,
             SLOT(togglebidiRendering(bool))
+        },
+        {
+            _ui->enableReverseUrlHints, Profile::ReverseUrlHints,
+            SLOT(toggleReverseUrlHints(bool))
         }
     };
     setupCheckBoxes(options, profile);
 
     // Setup the URL hints modifier checkboxes
     {
-        int modifiers = profile->property<int>(Profile::UrlHintsModifiers);
+        auto modifiers = profile->property<int>(Profile::UrlHintsModifiers);
         _ui->urlHintsModifierShift->setChecked((modifiers &Qt::ShiftModifier) != 0u);
         _ui->urlHintsModifierCtrl->setChecked((modifiers &Qt::ControlModifier) != 0u);
         _ui->urlHintsModifierAlt->setChecked((modifiers &Qt::AltModifier) != 0u);
@@ -1464,7 +1476,7 @@ void EditProfileDialog::setupAdvancedPage(const Profile::Ptr profile)
     connect(_ui->autoCursorColorButton, &QRadioButton::clicked, this, &Konsole::EditProfileDialog::autoCursorColor);
     connect(_ui->customColorSelectButton, &KColorButton::changed, this, &Konsole::EditProfileDialog::customCursorColorChanged);
 
-    int shape = profile->property<int>(Profile::CursorShape);
+    auto shape = profile->property<int>(Profile::CursorShape);
     _ui->cursorShapeCombo->setCurrentIndex(shape);
 
     connect(_ui->cursorShapeCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &Konsole::EditProfileDialog::setCursorShape);
@@ -1612,6 +1624,11 @@ void EditProfileDialog::updateUrlHintsModifier(bool)
     updateTempProfileProperty(Profile::UrlHintsModifiers, int(modifiers));
 }
 
+void EditProfileDialog::toggleReverseUrlHints(bool enable)
+{
+    updateTempProfileProperty(Profile::ReverseUrlHints, enable);
+}
+
 void EditProfileDialog::toggleBlinkingText(bool enable)
 {
     updateTempProfileProperty(Profile::BlinkingTextEnabled, enable);
@@ -1670,14 +1687,14 @@ void EditProfileDialog::setFontInputValue(const QFont &aFont)
     _ui->fontSizeInput->setValue(aFont.pointSizeF());
 }
 
-ColorSchemeViewDelegate::ColorSchemeViewDelegate(QObject *aParent) :
-    QAbstractItemDelegate(aParent)
+ColorSchemeViewDelegate::ColorSchemeViewDelegate(QObject *parent) :
+    QAbstractItemDelegate(parent)
 {
 }
 
 void ColorSchemeViewDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
 {
-    const ColorScheme *scheme = index.data(Qt::UserRole + 1).value<const ColorScheme *>();
+    const auto *scheme = index.data(Qt::UserRole + 1).value<const ColorScheme *>();
     QFont profileFont = index.data(Qt::UserRole + 2).value<QFont>();
     Q_ASSERT(scheme);
     if (scheme == nullptr) {
@@ -1745,5 +1762,5 @@ QSize ColorSchemeViewDelegate::sizeHint(const QStyleOptionViewItem &option, cons
     const int heightForWidth = (colorWidth * 2) + option.fontMetrics.height() + margin;
 
     // temporary
-    return QSize(width, heightForWidth);
+    return {width, heightForWidth};
 }
