@@ -427,6 +427,9 @@ public:
     /** Decreases the font size */
     void decreaseFontSize();
 
+    /** Reset the font size */
+    void resetFontSize();
+
     /**
      * Specified whether anti-aliasing of text in the terminal display
      * is enabled or not.  Defaults to enabled.
@@ -525,6 +528,16 @@ public:
         _urlHintsModifiers = Qt::KeyboardModifiers(modifiers);
     }
 
+    void setReverseUrlHintsEnabled(bool set)
+    {
+        _reverseUrlHints = set;
+    }
+
+    bool isReverseUrlHintsEnabled() const
+    {
+        return _reverseUrlHints;
+    }
+
     /**
      * Sets the terminal screen section which is displayed in this widget.
      * When updateImage() is called, the display fetches the latest character image from the
@@ -683,6 +696,13 @@ public Q_SLOTS:
      */
     void setCenterContents(bool enable);
 
+    /**
+     * Sets whether the background should change when the window loses focus
+     */
+    void setDimWhenInactive(bool shouldDim) {
+        _dimWhenInactive = shouldDim;
+    }
+
     // Used to show/hide the message widget
     void updateReadOnlyState(bool readonly);
     IncrementalSearchBar *searchBar() const;
@@ -785,7 +805,8 @@ protected:
     void inputMethodEvent(QInputMethodEvent *event) Q_DECL_OVERRIDE;
     QVariant inputMethodQuery(Qt::InputMethodQuery query) const Q_DECL_OVERRIDE;
 
-    void updateScrollBarPalette();
+    void onColorsChanged();
+
 protected Q_SLOTS:
 
     void scrollBarPositionChanged(int value);
@@ -848,6 +869,7 @@ private:
 
     // maps an area in the character image to an area on the widget
     QRect imageToWidget(const QRect &imageArea) const;
+    QRect widgetToImage(const QRect &widgetArea) const;
 
     // maps a point on the widget to the position ( ie. line and column )
     // of the character at that point. When the edge is true, it maps to
@@ -941,6 +963,7 @@ private:
     QVector<LineProperty> _lineProperties;
 
     ColorEntry _colorTable[TABLE_COLORS];
+
     uint _randomSeed;
 
     bool _resizing;
@@ -979,6 +1002,7 @@ private:
 
     Qt::KeyboardModifiers _urlHintsModifiers;
     bool _showUrlHint;
+    bool _reverseUrlHints;
     bool _openLinksByDirectClick;     // Open URL and hosts by single mouse click
 
     bool _ctrlRequiredForDrag; // require Ctrl key for drag selected text
@@ -1050,6 +1074,8 @@ private:
 
     qreal _opacity;
 
+    bool _dimWhenInactive;
+
     ScrollState _scrollWheelState;
     IncrementalSearchBar *_searchBar;
 
