@@ -23,16 +23,17 @@
 #include "ViewSplitter.h"
 
 // Qt
+#include <QDebug>
 
 // Konsole
 #include "ViewContainer.h"
 
 using Konsole::ViewSplitter;
-using Konsole::ViewContainer;
+using Konsole::TabbedViewContainer;
 
 ViewSplitter::ViewSplitter(QWidget *parent) :
     QSplitter(parent),
-    _containers(QList<ViewContainer *>()),
+    _containers(QList<TabbedViewContainer *>()),
     _recursiveSplitting(true)
 {
 }
@@ -46,16 +47,16 @@ void ViewSplitter::childEmpty(ViewSplitter *splitter)
     }
 }
 
-void ViewSplitter::adjustContainerSize(ViewContainer *container, int percentage)
+void ViewSplitter::adjustContainerSize(TabbedViewContainer *container, int percentage)
 {
-    int containerIndex = indexOf(container->containerWidget());
+    int containerIndex = indexOf(container);
 
     Q_ASSERT(containerIndex != -1);
 
     QList<int> containerSizes = sizes();
 
     const int oldSize = containerSizes[containerIndex];
-    const int newSize = static_cast<int>(oldSize * (1.0 + percentage / 100.0));
+    const auto newSize = static_cast<int>(oldSize * (1.0 + percentage / 100.0));
 
     const int perContainerDelta = (count() == 1) ? 0 : ((newSize - oldSize) / (count() - 1)) * (-1);
 
@@ -85,20 +86,13 @@ ViewSplitter *ViewSplitter::activeSplitter()
     return splitter;
 }
 
-void ViewSplitter::registerContainer(ViewContainer *container)
+void ViewSplitter::registerContainer(TabbedViewContainer *container)
 {
     _containers << container;
-    // Connecting to container::destroyed() using the new-style connection
-    // syntax causes a crash at exit. I don't know why. Using the old-style
-    // syntax works.
-    //connect(container , static_cast<void(ViewContainer::*)(ViewContainer*)>(&Konsole::ViewContainer::destroyed) , this , &Konsole::ViewSplitter::containerDestroyed);
-    //connect(container , &Konsole::ViewContainer::empty , this , &Konsole::ViewSplitter::containerEmpty);
-    connect(container, SIGNAL(destroyed(ViewContainer*)), this,
-            SLOT(containerDestroyed(ViewContainer*)));
-    connect(container, SIGNAL(empty(ViewContainer*)), this, SLOT(containerEmpty(ViewContainer*)));
+    connect(container, SIGNAL(empty(TabbedViewContainer*)), this, SLOT(containerEmpty(TabbedViewContainer*)));
 }
 
-void ViewSplitter::unregisterContainer(ViewContainer *container)
+void ViewSplitter::unregisterContainer(TabbedViewContainer *container)
 {
     _containers.removeAll(container);
     disconnect(container, nullptr, this, nullptr);
@@ -134,14 +128,14 @@ bool ViewSplitter::recursiveSplitting() const
     return _recursiveSplitting;
 }
 
-void ViewSplitter::removeContainer(ViewContainer *container)
+void ViewSplitter::removeContainer(TabbedViewContainer *container)
 {
     Q_ASSERT(containers().contains(container));
 
     unregisterContainer(container);
 }
 
-void ViewSplitter::addContainer(ViewContainer *container, Qt::Orientation containerOrientation)
+void ViewSplitter::addContainer(TabbedViewContainer *container, Qt::Orientation containerOrientation)
 {
     ViewSplitter *splitter = activeSplitter();
 
@@ -149,7 +143,7 @@ void ViewSplitter::addContainer(ViewContainer *container, Qt::Orientation contai
         || containerOrientation == splitter->orientation()
         || !_recursiveSplitting) {
         splitter->registerContainer(container);
-        splitter->addWidget(container->containerWidget());
+        splitter->addWidget(container);
 
         if (splitter->orientation() != containerOrientation) {
             splitter->setOrientation(containerOrientation);
@@ -161,16 +155,16 @@ void ViewSplitter::addContainer(ViewContainer *container, Qt::Orientation contai
         connect(newSplitter, &Konsole::ViewSplitter::empty, splitter,
                 &Konsole::ViewSplitter::childEmpty);
 
-        ViewContainer *oldContainer = splitter->activeContainer();
-        const int oldContainerIndex = splitter->indexOf(oldContainer->containerWidget());
+        TabbedViewContainer *oldContainer = splitter->activeContainer();
+        const int oldContainerIndex = splitter->indexOf(oldContainer);
 
         splitter->unregisterContainer(oldContainer);
 
         newSplitter->registerContainer(oldContainer);
         newSplitter->registerContainer(container);
 
-        newSplitter->addWidget(oldContainer->containerWidget());
-        newSplitter->addWidget(container->containerWidget());
+        newSplitter->addWidget(oldContainer);
+        newSplitter->addWidget(container);
         newSplitter->setOrientation(containerOrientation);
         newSplitter->updateSizes();
         newSplitter->show();
@@ -179,11 +173,16 @@ void ViewSplitter::addContainer(ViewContainer *container, Qt::Orientation contai
     }
 }
 
-void ViewSplitter::containerEmpty(ViewContainer * /*container*/)
+void ViewSplitter::containerEmpty(TabbedViewContainer * myContainer)
 {
+    _containers.removeAll(myContainer);
+    if (count() == 0) {
+        emit empty(this);
+    }
+
     int children = 0;
-    foreach (ViewContainer *container, _containers) {
-        children += container->views().count();
+    foreach (auto container, _containers) {
+        children += container->count();
     }
 
     if (children == 0) {
@@ -191,20 +190,9 @@ void ViewSplitter::containerEmpty(ViewContainer * /*container*/)
     }
 }
 
-void ViewSplitter::containerDestroyed(ViewContainer *container)
-{
-    Q_ASSERT(_containers.contains(container));
-
-    _containers.removeAll(container);
-
-    if (count() == 0) {
-        emit empty(this);
-    }
-}
-
 void ViewSplitter::activateNextContainer()
 {
-    ViewContainer *active = activeContainer();
+    TabbedViewContainer *active = activeContainer();
 
     int index = _containers.indexOf(active);
 
@@ -223,7 +211,7 @@ void ViewSplitter::activateNextContainer()
 
 void ViewSplitter::activatePreviousContainer()
 {
-    ViewContainer *active = activeContainer();
+    TabbedViewContainer *active = activeContainer();
 
     int index = _containers.indexOf(active);
 
@@ -236,23 +224,23 @@ void ViewSplitter::activatePreviousContainer()
     setActiveContainer(_containers.at(index));
 }
 
-void ViewSplitter::setActiveContainer(ViewContainer *container)
+void ViewSplitter::setActiveContainer(TabbedViewContainer *container)
 {
-    QWidget *activeView = container->activeView();
+    QWidget *activeView = container->currentWidget();
 
     if (activeView != nullptr) {
         activeView->setFocus(Qt::OtherFocusReason);
     }
 }
 
-ViewContainer *ViewSplitter::activeContainer() const
+TabbedViewContainer *ViewSplitter::activeContainer() const
 {
     if (QWidget *focusW = focusWidget()) {
-        ViewContainer *focusContainer = nullptr;
+        TabbedViewContainer *focusContainer = nullptr;
 
         while (focusW != nullptr) {
-            foreach (ViewContainer *container, _containers) {
-                if (container->containerWidget() == focusW) {
+            foreach (TabbedViewContainer *container, _containers) {
+                if (container == focusW) {
                     focusContainer = container;
                     break;
                 }
