@@ -94,12 +94,12 @@ void TerminalCharacterDecoderTest::testHTMLDecoder_data()
     /* Notes:
      * TODO: need to add foregroundColor, backgroundColor, and isRealCharacter
      */
-    QTest::newRow("simple text with default rendition") << "hello" << QVector<RenditionFlags>(6).fill(DEFAULT_RENDITION) <<  "<span style=\"font-family:monospace\"><span style=\"color:#000000;background-color:#ffffff;\">hello</span><br></span>";
-    QTest::newRow("simple text with bold rendition") << "hello" << QVector<RenditionFlags>(6).fill(RE_BOLD) <<  "<span style=\"font-family:monospace\"><span style=\"font-weight:bold;color:#000000;background-color:#ffffff;\">hello</span><br></span>";
+    QTest::newRow("simple text with default rendition") << "hello" << QVector<RenditionFlags>(6).fill(DEFAULT_RENDITION) <<  R"(<span style="font-family:monospace"><span style="color:#000000;background-color:#ffffff;">hello</span><br></span>)";
+    QTest::newRow("simple text with bold rendition") << "hello" << QVector<RenditionFlags>(6).fill(RE_BOLD) <<  R"(<span style="font-family:monospace"><span style="font-weight:bold;color:#000000;background-color:#ffffff;">hello</span><br></span>)";
     // The below is wrong; only the first rendition is used (eg ignores the |)
-    QTest::newRow("simple text with underline and italic rendition") << "hello" << QVector<RenditionFlags>(6).fill(RE_UNDERLINE|RE_ITALIC) <<  "<span style=\"font-family:monospace\"><span style=\"font-decoration:underline;color:#000000;background-color:#ffffff;\">hello</span><br></span>";
+    QTest::newRow("simple text with underline and italic rendition") << "hello" << QVector<RenditionFlags>(6).fill(RE_UNDERLINE|RE_ITALIC) <<  R"(<span style="font-family:monospace"><span style="font-decoration:underline;color:#000000;background-color:#ffffff;">hello</span><br></span>)";
 
-    QTest::newRow("text with &") << "hello &there" << QVector<RenditionFlags>(6).fill(DEFAULT_RENDITION) <<  "<span style=\"font-family:monospace\"><span style=\"color:#000000;background-color:#ffffff;\">hello &amp;there</span><br></span>";
+    QTest::newRow("text with &") << "hello &there" << QVector<RenditionFlags>(6).fill(DEFAULT_RENDITION) <<  R"(<span style="font-family:monospace"><span style="color:#000000;background-color:#ffffff;">hello &amp;there</span><br></span>)";
 }
 
 void TerminalCharacterDecoderTest::testHTMLDecoder()
